pub mod compute_char_freq;
pub mod expand_names;
pub mod global_defs;
pub mod hygiene;
pub mod mangle_names;
pub mod mangle_props;
pub mod postcompress;
pub mod precompress;
